/** Helper method to get reference from path, the path can be either to a Document or Collection */
import { AngularFirestore, AngularFirestoreDocument, DocumentData, DocumentReference } from '@angular/fire/firestore';
import { CollectionReference } from '@angular/fire/firestore/interfaces';
import { FirestoreItem } from './models/firestoreItem';
import { AngularFirestoreCollection } from '@angular/fire/firestore/collection/collection';
import { Observable } from 'rxjs/dist/types';
/** Helper method to get reference from path, the path can be either to a Document or Collection */
export declare function getRefFromPath(path: string, ngFirestore: AngularFirestore): DocumentReference | CollectionReference;
/** If given the path to a Document it returns the parent AngularFirestoreCollection,
 * if given a path to a collection it just turns it into a AngularFirestoreCollection
 */
export declare function getCollectionFsFromPath<A extends FirestoreItem>(path: string, ngFirestore: AngularFirestore): AngularFirestoreCollection<A>;
/**
 * Get AngularFirestoreDocument from path
 *
 * @param path the path to the AngularFirestoreDocument
 * @param ngFirestore the AngularFirestore object
 */
export declare function getDocFsFromPath(path: string, ngFirestore: AngularFirestore): AngularFirestoreDocument;
/**
 * Returns the next higher level doc from either a collection or a doc path
 *
 * @param path the path to the AngularFirestoreDocument
 * @param ngFirestore the AngularFirestore object
 */
export declare function getParentDocFsFromPath<A extends FirestoreItem>(path: string, ngFirestore: AngularFirestore): AngularFirestoreDocument<A>;
/**
 * Simple check if Document exists, returns true if Document exist
 *
 * @param docFs AngularFirestoreDocument to check if exist
 */
export declare function isDocExist$(docFs: AngularFirestoreDocument<DocumentData>): Observable<boolean>;
/**
 * Get the AngularFirestoreDocument object for a firestore DocumentReference
 *
 * AngularFirestore and Firestore uses different references for Documents and Collections.
 *
 * @param ref Firestore DocumentReference to Document
 * @param ngFirestore the AngularFirestore object
 */
export declare function getDocFsFromRef(ref: DocumentReference, ngFirestore: AngularFirestore): AngularFirestoreDocument;
/**
 * Add createdDate to the object, if createdDate already exists then we do not overwrite it
 *
 * @param data data where the createdData will be added
 */
export declare function addCreatedDate<A>(data: A): A;
/**
 * Add modifiedDate to the object
 *
 * @param data data where the modifiedDate will be added
 */
export declare function addModifiedDate<A>(data: A): A;
/**
 * Add createdBy to the object
 *
 * @param createdBy profile, user or any type of data
 */
export declare function addCreatedBy<A>(data: A, createdBy: any): A;
/**
 * Firestore saves time as timestamps and javascript uses Date objects.
 * This functions helps convert the createdDate and modifiedDate from timestamp
 * to Date()
 *
 * @param data data that contains 'createdDate' and/or 'modifiedDate'
 */
export declare function convertTimestampToDate<A extends FirestoreItem>(data: A): A;
